bigben/clock

A clock.

Types

A clock.

pub opaque type Clock

Values

pub fn from_fake(clock: fake_clock.FakeClock) -> Clock

Returns a new Clock constructed from the given FakeClock.

pub fn new() -> Clock

Returns a new Clock.

pub fn now(clock: Clock) -> birl.Time

Returns the current time on the given Clock, in UTC.

Search Document