bigben/fake_clock
A fake clock for manipulating the flow of time.
Types
Values
pub fn advance(
clock: FakeClock,
duration: duration.Duration,
) -> Nil
Advances the given FakeClock by the specified duration.
A fake clock for manipulating the flow of time.
pub fn advance(
clock: FakeClock,
duration: duration.Duration,
) -> Nil
Advances the given FakeClock by the specified duration.